@@ -18,11 +18,10 @@
   "Un-freezes and re-selects the Dialogue buffer in another window.
    With argument, recenter with that argument."
   (interactive "P")
-  (if (irchat-frozen irchat-Dialogue-buffer)
-      (irchat-freeze-toggle irchat-Dialogue-buffer))
-  (if (irchat-ownfrozen irchat-Dialogue-buffer)
-      (irchat-ownfreeze-toggle irchat-Dialogue-buffer))
-  (setq irchat-freeze nil)
+  (if (irchat-frozen (car irchat-D-buffer))
+      (irchat-freeze-toggle (car irchat-D-buffer)))
+  (if (irchat-ownfrozen (car irchat-D-buffer))
+      (irchat-ownfreeze-toggle (car irchat-D-buffer)))
   (setq irchat-freeze-indicator "-")
   (setq irchat-ownfreeze nil)
   (setq irchat-ownfreeze-indicator "-")
@@ -583,7 +582,6 @@ be a string to send NICK upon entering."
       (setq irchat-freeze-indicator "-")
     (setq irchat-freeze-indicator "F"))
   (switch-to-buffer (current-buffer))
-  (setq irchat-freeze (not irchat-freeze))
   (irchat-freeze-toggle (car irchat-D-buffer))
   )
 
