@@ -111,7 +111,9 @@
 		     (buffer-substring (match-beginning 3) (match-end 3))))
 
       (set-buffer irchat-Dialogue-buffer)
+      (setq irchat-current-function (list prefix message))
       (irchat-handle-message-2 prefix message rest-of-line)
+      (setq irchat-current-function (list "" ""))
       (set-buffer obuf)
       (delete-region beg end))))
 
