@@ -334,6 +334,10 @@ If already connected, just pop up the windows."
 	  (if (not irchat-keep-buffers)
 	      (erase-buffer))
 	  (sit-for 0))
+	(if (irchat-frozen (car irchat-D-buffer))
+	    (progn
+	      (setq irchat-freeze-indicator "-")
+	      (irchat-freeze-toggle (car irchat-D-buffer))))
 	(irchat-Dialogue-setup-buffer)
 	(irchat-KILLS-setup-buffer)
 	(irchat-IGNORED-setup-buffer)
@@ -616,17 +620,18 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	   (nbuf (get-buffer buffer))
 	   (narrow)
 	   (frozen)
-	   (spoint nil))
+	   (spoint nil)
+	   (oldwstart nil))
 
       (if (not nbuf)
 	  (save-excursion
 	    (setq nbuf (irchat-get-buffer-create buffer))
 	    (set-buffer nbuf)
 	    (irchat-Dialogue-mode)))
-	  
+
       (setq bufintern (intern (format "%s" nbuf) irchat-obarray))
       (setq narrow (get bufintern 'narrow))
-      (setq frozen (get bufintern 'frozen))
+      (setq frozen (irchat-frozen nbuf))
       (set-buffer nbuf)
       ;;
       ;; have to use this kludge because save-restriction
@@ -634,15 +639,18 @@ One is for entering commands and text, the other displays the IRC dialogue."
       ;; and point-max a constant, not the distance between
       ;; point and mark, seesh mta Fri Jan  3 12:43:01 EET 1992
       ;;
+      (setq oldwstart (window-start (selected-window)))
+      (setq spoint (point))
       (if narrow
 	  (progn
-	    (setq spoint (point))
 	    (widen)))
       (goto-char (point-max))
       (if buffer-read-only
 	  (setq buffer-read-only nil))
-      (insert string)
+      (if (not (irchat-is-message-ignored string))
+	  (insert string))
       (setq buffer-read-only t)
+      (goto-char spoint)
       (if narrow
 	  (progn
 	    (narrow-to-region (car narrow)
@@ -661,6 +669,8 @@ One is for entering commands and text, the other displays the IRC dialogue."
 				 win)
 		(set-window-start win (point))
 		(goto-char (point-max))))))
+      (if (and frozen (equal nbuf obuf))
+	  (set-window-start (selected-window) oldwstart))
       (set-buffer obuf))
     nil))
 
@@ -721,6 +731,49 @@ One is for entering commands and text, the other displays the IRC dialogue."
 		(delete-region (point-min) (point))))
 	  (setq buflist (cdr buflist)))
 	(set-buffer obuf))))
+
+(defun irchat-is-message-ignored (string)
+  (let ((mylist irchat-ignore-list)
+	(found nil)
+	(case-fold-search t))
+    (catch 'ignore
+      (while mylist
+	(let ((msg nil) 
+	      (str nil)
+	      (who nil)
+	      (mymylist (car mylist)))
+	  (if (listp (car mymylist))
+	      (setq msg (car (car mymylist))
+		    str (car (cdr (car mymylist))))
+	    (if (fboundp (car mymylist))
+		(let ((msgstr (apply (car mymylist) (list string))))
+		  (setq msg (car msgstr)
+			str (car (cdr msgstr))))
+	      (message "Malformed ignore-list, no msg+str function.")))
+	  (if (listp (car (cdr mymylist)))
+	      (setq who (car (cdr mymylist)))
+	    (if (fboundp (car (cdr mymylist)))
+		(setq who (apply (car (cdr mymylist)) (list string)))
+	      (if (not (car (cdr mylist)))
+		  (message "Malformed ignore-list, no user function."))))
+	  (if (or msg str)
+	      (if (or
+		   (and msg (string-match msg (car (cdr irchat-current-function))))
+		   (and str (string-match str string)))
+		  (let ((mywho who))
+		    (while mywho
+		      (if (string-match (car mywho) (car irchat-current-function))
+			  (progn
+			    (setq found t)
+			    (throw 'ignore t))
+			)
+		      (setq mywho (cdr mywho))))
+		)))
+	(setq mylist (cdr mylist))))
+    found
+    )
+  )
+
 ;;;
 ;;; eof
 ;;;
