@@ -224,6 +224,42 @@ won't be displayed.")
   "*A list of logon names (user@host.dom.ain). Messages from them
 won't be displayed.")
 
+;;;
+;;; New Ignore
+;;;
+(defvar irchat-ignore-list nil
+  "*A list of lists that contain ignore-info.
+It is list of lists that contain two elements,
+first element may be two item list of
+(match-for-messagetype match-for-string-in-message)
+match-for-messagetype may be nil,
+match-for-string-in-message may be nil,
+or
+name of function that returns this list, the function takes
+one argument, the string we are asked to ignore.
+The other argument is
+(list-of-users) 
+list-of-users may be nil (in case it does not match),
+or 
+name of function returning that returns similar list, the
+function takes one argument, the string we are asked to ignore.
+
+(setq irchat-ignore-list
+      (list
+       (list (list \"msg\" nil) (list \"!user\" \"@host\"))
+       (list (list \"privmsg\" nil) 'irchat-own-ignore-who)
+       (list 'irchat-own-ignore-check (list \"com\"))
+       (list (list nil \"fuck\") (list \".*\"))
+       )
+      )
+The previous ignores normal msg`s (not used so much anymore)
+from username matching 'user' or from host 'host'.
+Then any privmsg from list that irchat-own-ignore-who return.
+Then if the user is from .com (or has com somewhere in name
+and the irchat-own-ignore-check returns message-type and/or string.
+The last ignores all messages that contain the word `fuck`.
+")
+
 ;;;
 ;;; Buffer display variables
 ;;;
